<?php

class mobile_plugin_class {
	var $plugin_hooks;
	var $plugin_whitelist = array(
		"akismet",
		"obox-mobile",
		"woo-tumblog",
	); // plugin_whitelist

	// List all the files & their relative path in a specific directory
	public function list_files( $dir, $extension, $rel_path = "" ) {
		$files = array();

		$d = opendir( $dir );
		if ( $d ) {
			while ( FALSE !== ( $f = readdir( $d ) ) ) {
				if ( $f == "." || $f == ".." || $f == ".svn" || $f == "._.DS_Store" ) continue;

				if ( is_dir( $dir . "/" . $f ) ) {
					$files = array_merge(
						$files,
						$this->list_files( $dir . "/" . $f, $extension, $rel_path . "/" . $f )
					); // array_merge
				} else {
					if ( FALSE !== strpos( $f, $extension ) ) {
						$files[] = $rel_path . "/" . $f;
					} // if filetype
				} // if is dir
			} // while readdir

			closedir( $d );
		} // if opendir

		return $files;
	} // list_files

	// Generate plugin list and add the plugins as options in OBOX
	public function plugin_list() {
		global $mobile_plugin_options;

		foreach ( $this->list_files( WP_PLUGIN_DIR, "php" ) AS $plugin_file ) {
			$path_info = explode( "/", $plugin_file );

			if ( count( $path_info ) > 2 ) {
				$plugin_slug = $path_info[1];

				if ( in_array( $plugin_slug, $this->plugin_whitelist ) ) continue;

				if (
					in_array( substr( $plugin_file, 1, strlen( $plugin_file ) ), get_option( "active_plugins" ) ) &&
					!isset( $this->plugin_hooks[ $plugin_slug ] )
				) {
					array_unshift(
						$mobile_plugin_options["plugins"][0]["sub_elements"],
						array(
							"label" => $this->get_friendly_plugin_name( $plugin_slug ),
							"description" => "",
							"name" => "mobile_disable_" . str_replace( "-", "_", $plugin_slug ),
							"default" => "",
							"id" => $plugin_slug,
							"input_type" => "checkbox",
						)
					); // array_unshift

					$this->plugin_hooks[ $plugin_slug ] = 1;
				} // if plugin active
			} // if count pathinfo
		} // foreach plugin
	} // plugin_list

	// Find the real name of the plugin, including caps, spaces etc.
	public function get_friendly_plugin_name( $name ) {
		$plugin_file = WP_PLUGIN_DIR . "/" . $name . "/" . $name . ".php";
		if ( file_exists( $plugin_file ) ) {
			$contents = file_get_contents( $plugin_file );

			if ( $contents ) {
				if ( preg_match( "#Plugin Name: (.*)\n#", $contents, $matches ) ) {
					return $matches[1];
				} // if match
			} // if contents
		} // if file exists

		$all_files = glob( WP_PLUGIN_DIR . "/" . $name . "/*.php" );
		if ( $all_files ) {
			foreach ( $all_files AS $some_file ) {
				if ( file_exists( $some_file ) ) {
					$contents = file_get_contents( $some_file );
					if ( $contents ) {
						if ( preg_match( "#Plugin Name: (.*)\n#", $contents, $matches ) ) {
							return $matches[1];
						} // if match
					} // if contents
				} // if file exists
			} // for each all files
		} // if all files

		return str_replace( "_" , " ", $name );
	} // get_friendly_plugin_name

	public function disable_plugins() {
		global $mobile_plugin_options;

		foreach ( $mobile_plugin_options["plugins"][0]["sub_elements"] AS $plugins ) {
			$option = $plugins["name"];
			$plugin_file = $plugins["id"];
			$folder = WP_PLUGIN_DIR . "/" . $plugin_file;

			if ( !get_option( $option ) || get_option( $option ) == "false" || in_array( $plugin_file, $this->plugin_whitelist ) ) {
				$plugin_hooks = $this->load_plugin_hooks( $folder );

				if ( !empty( $plugin_hooks ) ) {
					foreach ( $plugin_hooks AS $name => $hook_info ) {
						if ( isset( $hook_info->filters ) && count( $hook_info->filters ) ) {
							$this->_remove_actions( $hook_info->filters );
						} else if ( isset( $hook_info->actions ) && count( $hook_info->actions ) ) {
								$this->_remove_actions( $hook_info->actions );
							} // if actions or filters
					} // for each hook
				} // if hooks
			} // if option
		} // for each plugin
	} // disable_plugins

	private function _remove_actions( $actions ) {
		foreach ( $actions AS $action ) {
			if ( $action->priority ) {
				remove_action( $action->hook, $action->hook_function, $action->priority );
			} else {
				remove_action( $action->hook, $action->hook_function );
			} // if priority
		} // for each action
	} // _remove_actions

	// Find the hooks for the plugins
	public function load_plugin_hooks( $folder = WP_PLUGIN_DIR ) {
		$php_files = $this->list_files( $folder, "php" );

		foreach ( $php_files AS $plugin_file ) {
			$path_info = explode( "/", $plugin_file );

			if ( count( $path_info ) > 0 ) {
				$plugin_slug = $path_info[1];
				if ( in_array( $plugin_slug, $this->plugin_whitelist ) ) continue;

				$contents = file_get_contents( $folder . $plugin_file );

				if ( !isset( $this->plugin_hooks[ $plugin_slug ] ) ) {
					$this->plugin_hooks[ $plugin_slug ] = new stdClass;
				}

				// Default actions
				if ( preg_match_all( "#add_action\([ ]*[\'\"]+(.*)[\'\"]+,[ ]*[\'\"]+(.*)[\'\"]+[ ]*(\s*[,]\s*+(.*))*\)\s*;#iU", $contents, $matches ) ) {
					for ( $i = 0; $i < count( $matches[0] ); $i++ ) {
						if ( FALSE === strpos( $matches[2][$i], " " ) ) {
							$this->plugin_hooks[ $plugin_slug ]->actions[] = (object) array(
								"hook" => $matches[1][ $i ],
								"hook_function" => $matches[2][ $i ],
								"priority" => ( isset( $matches[4][ $i ] ) && ( $matches[4][ $i ] > 0 ) ) ? $matches[4][ $i ] : FALSE,
							); // array
						} // if strpos
					} // for each match
				} // if match

				// Default filters
				if ( preg_match_all( "#add_filter\([ ]*[\'\"]+(.*)[\'\"]+,[ ]*[\'\"]+(.*)[\'\"]+[ ]*(\s*[,]\s*+(.*))*\)\s*;#iU", $contents, $matches ) ) {
					for ( $i = 0; $i < count( $matches[0] ); $i++ ) {
						if ( FALSE === strpos( $matches[2][ $i ], " " ) ) {
							$this->plugin_hooks[ $plugin_slug ]->filters[] =  (object) array(
								"hook" => $matches[1][ $i ],
								"hook_function" => $matches[2][ $i ],
								"priority" => ( isset( $matches[4][$i] ) && ( $matches[4][ $i ] > 0 ) ) ? $matches[4][ $i ] : FALSE,
							); // array
						} // if match
					} // for each match
				} // pre match all
			} // if count path
		} // foreach php file

		return $this->plugin_hooks;
	} // load_plugin_hook

} // mobile_plugin_class

// Disable Unwanted Plugins
function mobile_check_plugins() {
	global $obox_mobile;
	/*if (
		!is_admin() &&
		$obox_mobile->allow_mobile() === TRUE &&
		$obox_mobile->site_style() == "mobile"
	) {
		$plugins = new mobile_plugin_class();
		$plugins->disable_plugins();
	}*/

} // mobile_check_plugins

add_action( "plugins_loaded", "mobile_check_plugins" );
