<?php
/**
 * All functions in this file are common elements accessed by all Obox Mobile themes.
 **/
function mobile_site_title() {
	global $page, $paged, $post;
	wp_title( '|', true, 'right' );
	bloginfo( 'name' );
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		echo " | $site_description";
	if ( $paged >= 2 || $page >= 2 )
		echo ' | ' . sprintf( __( 'Page %s', 'ocmx' ), max( $paged, $page ) );
} //mobile_site_title

function mobile_head_meta() {
	global $obox_mobile;
	$mobile_options = $obox_mobile->get_options(); ?>
	<meta name="apple-mobile-web-app-capable" content="no" />
	<meta name="viewport" content="initial-scale=1,maximum-scale=1,user-scalable=no">
	<meta http-equiv="Content-Type" content="<?php bloginfo( "html_type" ); ?>; charset=<?php bloginfo( "charset" ); ?>" />
	<link rel="alternate" type="application/rss+xml" title="<?php bloginfo( "name" ); ?> RSS Feed" href="<?php bloginfo( "rss2_url" ); ?>" />
	<?php $fb_image = mobile_get_fb_image();
	if(is_home()) { ?>
		<meta property="og:title" content="<?php bloginfo('name'); ?>"/>
		<meta property="og:description" content="<?php bloginfo('description'); ?>"/>
		<meta property="og:url" content="<?php echo home_url(); ?>"/>
		<?php if( isset( $fb_image ) && $fb_image != "" ){ ?>
			<meta property="og:image" content="<?php echo $fb_image; ?>"/>
		<?php } // if $fb_image ?>
		<meta property="og:type" content="<?php echo "website";?>"/>
		<meta property="og:site_name" content="<?php bloginfo('name'); ?>"/>
	<?php } else {
		global $post; ?>
		<meta property="og:title" content="<?php the_title(); ?>"/>
		<meta property="og:description" content="<?php echo strip_tags($post->post_excerpt); ?>"/>
		<meta property="og:url" content="<?php the_permalink(); ?>"/>
		<?php if( isset( $fb_image ) && $fb_image != "" ){ ?>
			<meta property="og:image" content="<?php echo $fb_image; ?>"/>
		<?php } // if $fb_image ?>
		<meta property="og:type" content="<?php echo "article"; ?>"/>
		<meta property="og:site_name" content="<?php bloginfo('name'); ?>"/>
	<?php } // is_home()
} // mobile_head_meta

function mobile_social_links() {
	global $post, $obox_mobile;
	$mobile_options = $obox_mobile->get_options();

	if (
		( !isset( $mobile_options[ "social_link_usage" ] ) ) ||
		( $mobile_options[ "social_link_usage" ] == "off" ) ||
		( ( is_single() || is_archive() ) && $mobile_options[ "social_link_usage" ] == "pages" ) ||
		( is_page() && $mobile_options[ "social_link_usage" ] == "posts" )
	) {
		return FALSE;
	} // if

	$mobile_facebook = $mobile_options[ "facebook" ];
	$mobile_twitter = $mobile_options[ "twitter" ];
	$mobile_googleplus = $mobile_options[ "googleplus" ];
	if ( $mobile_facebook !== false || $mobile_twitter !== false || $mobile_googleplus !== false ) : ?>
		<ul class="post-meta clearfix">
			<li class="social-links">
				<?php if ( $mobile_facebook !== false ) : ?>
					<div class="social-facebook">
						<iframe src="//www.facebook.com/plugins/like.php?href=<?php echo esc_url( get_permalink( $post->ID ) ); ?>&amp;send=false&amp;layout=button_count&amp;width=50&amp;show_faces=true&amp;font=tahoma&amp;colorscheme=light&amp;action=like&amp;height=21" scrolling="no" frameborder="0" style="border:none; overflow:hidden; width:50px; height:21px;" allowTransparency="true"></iframe>
					</div>
				<?php endif; // mobile_facebook ?>

				<?php if ( $mobile_twitter !== false ) : ?>
					<div class="social-twitter">
						<a href="https://twitter.com/share" class="twitter-share-button" data-text="<?php wp_title( '|', true, 'right' ); bloginfo( 'name' ); ?>">Tweet</a>
						<script>!function(d,s,id){var js,fjs=d.getElementsByTagName(s)[0],p=/^http:/.test(d.location)?'http':'https';if(!d.getElementById(id)){js=d.createElement(s);js.id=id;js.src=p+'://platform.twitter.com/widgets.js';fjs.parentNode.insertBefore(js,fjs);}}(document, 'script', 'twitter-wjs');</script>
					</div>
				<?php endif; // mobile_twitter ?>

				<?php if ( $mobile_googleplus !== false ) : ?>
					<div class="social-google">
						<!-- Place this tag where you want the +1 button to render -->
						<g:plusone size="medium" count="false" href="<?php echo get_permalink( $post->ID ); ?>"></g:plusone>

						<!-- Place this tag after the last plusone tag -->
						<script type="text/javascript">
						  (function() {
							var po = document.createElement('script'); po.type = 'text/javascript'; po.async = true;
							po.src = 'https://apis.google.com/js/plusone.js';
							var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(po, s);
						  })();
						</script>
					</div>
				<?php endif; // mobile_googleplus ?>
			</li>
		</ul>
<?php endif; // if all
} // mobile_social_links

add_action( "mobile_social_links", "mobile_social_links" );

function mobile_post_meta( $wrap = "h5" ) {
	global $post, $obox_mobile;
	$mobile_options = $obox_mobile->get_options();

	if (
		( $mobile_options[ "post_meta" ] == "off" ) ||
		( ( is_single() || is_archive() ) && $mobile_options[ "post_meta" ] == "pages" ) ||
		( is_page() && $mobile_options[ "post_meta" ] == "posts" )
	) {
		return FALSE;
	} // if
	?>
	<<?php echo $wrap; ?> class="date">
		<?php
		if ( $mobile_options[ "post_date" ] !== false ) {
			echo date( "F j, Y", strtotime( $post->post_date ) );
			$hasdate = 1;
		} // if mobile_post_date

		if ( $mobile_options[ "post_author" ] !== false ) {
			if ( isset( $hasdate ) ) {
				_e( " by", "obox-mobile" );
			} else {
				_e( "By", "obox-mobile" );
			}
		?>
			<?php echo the_author_posts_link(); ?>
		<?php
		} // mobile_post_author

		if ( !is_page() ) {
			if ( $mobile_options[ "post_tags" ] !== false ) {
				the_tags( _( "Tagged: " ), ', ' );
			} // if mobile_post_tags

			if ( $mobile_options[ "post_categories" ] !== false ) {
				_e( " Posted In ", "obox-mobile" );
				the_category( ', ' );
			} // if mobile_post_categories
		} // if not page
		?>
	</<?php echo $wrap; ?>>
<?php
} // mobile_post_meta

add_action( "mobile_post_meta", "mobile_post_meta" );

function mobile_author_bio() {
	global $obox_mobile;
	$mobile_options = $obox_mobile->get_options();
	if (
		( $mobile_options[ "author_display" ] == "off" ) ||
		( ( is_single() || is_archive() ) && $mobile_options[ "author_display" ] == "pages" ) ||
		( is_page() && $mobile_options[ "author_display" ] == "posts" )
	) {
		return FALSE;
	} // if
	?>
	<div class="author">
		<a href="#" class="author-avatar"><?php echo get_avatar( get_the_author_meta( 'email' ), "45" ); ?></a>
		<div class="author-copy">
			<h4 class="author-name"><?php echo the_author_posts_link(); ?></h4>
			<p><?php the_author_meta( 'description' ); ?></p>
		</div>
	</div>
<?php
} // mobile_author_bio

add_action( "mobile_author_bio", "mobile_author_bio" );

function mobile_slider() {
	/* FEATURE WIDGET */
	global $obox_mobile, $slider_widget;
	$mobile_options = $obox_mobile->get_options();
	if ( $obox_mobile->allow_slider() && !is_paged() ) {
		the_widget(
			'slider_widget',
			array(
				"post_category" => $mobile_options[ "slider_category" ],
				"post_count" => $mobile_options[ "slider_count" ],
			)
		); // widget
	} // if allow slider and is paged
} // mobile_do_slider

add_action( "mobile_slider", "mobile_slider" );

function mobile_breadcrumbs( $wrap_start = '<h2  class="category-title">', $wrap_end = '</h2>' ) {
	global $post;
	the_post();

	echo $wrap_start;
	if ( is_day() ) {
		_e( 'Daily Archives: ' . get_the_date() );
	} elseif ( is_month() ) {
		_e( 'Monthly Archives: ' . get_the_date( _x( 'F Y', 'monthly archives date format', 'obox-mobile' ) ) );
	} elseif ( is_year() ) {
		_e( 'Yearly Archives: ' . get_the_date( _x( 'Y', 'yearly archives date format', 'obox-mobile' ) ) );
	} elseif ( is_tag() ) {
		_e( 'Tag: '.single_tag_title( '', false ) );
	} elseif ( is_author() ){
		_e( 'Author: '.get_the_author() );
	} else if ( is_archive() ) {
		_e( 'Category: '.single_cat_title( '', false ) );
	} else if ( is_search() ) {
		_e( "Your search results for: " );
		the_search_query();
	} // if page type

	echo $wrap_end;

	// Rewind the post query to its original state
	rewind_posts();
} // mobile_breadcrumbs

function mobile_comments($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment; ?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
		<a href="#" class="comment-avatar"><?php echo get_avatar($comment, 45); ?> </a>
		<div class="comment-post">
			<h4 class="comment-name">
				<a href="<?php comment_author_url(); ?>" class="commentor_url" name="comment-<?php echo $comment->comment_ID; ?>" rel="nofollow"><?php comment_author(); ?></a>
			</h4>
			<h5 class="date"><?php comment_date("d M Y"); ?></h5>
			<?php if ( $comment->comment_approved == "0" ) : ?>
				<p><?php _e( "Comment is awaiting moderation.", "obox-mobile" ); ?></p>
			<?php else :
				comment_text();
			endif; ?>
			<?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
		</div>
<?php } // mobile_comments

function mobile_get_fb_image() {
	global $post;
	$src = wp_get_attachment_image_src( get_post_thumbnail_id($post->ID), '', '' );
	$fbimage = null;
	if ( has_post_thumbnail($post->ID) ) {
		$fbimage = $src[0];
	} else {
		global $post, $posts;
		$fbimage = '';
		$output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i',
		$post->post_content, $matches);
		if(!empty($matches[1]))
			$fbimage = $matches [1] [0];
	}
	if(empty($fbimage)) {
		$fbimage = get_the_post_thumbnail($post->ID);
	}
	return $fbimage;
} // mobile_get_fb_image